@@ -237,10 +237,24 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
         overall_status["about"]["member"] = result["member"]
         overall_status["unpreserved-items"] = list()
 
+        if result["DOI"] == "10.16995/glossa.8784":
+            print("HERE")
+            year_published = (
+                result["published"]["date-parts"][0][0]
+                if "published" in result
+                else None
+            )
+            print(year_published)
+            print(int(year_published) < int(date.today().year))
+
         # we can only work with journal articles
         # we exclude journal articles from the current year because they
         # most likely have not been ingested into digital preservation
         # systems yet
+
+        # increment the sample count
+        overall_status["sample-count"] += 1
+
         if "type" in result and result["type"] == "journal-article":
             year_published = (
                 result["published"]["date-parts"][0][0]
@@ -248,7 +262,7 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                 else None
             )
 
-            if year_published and str(year_published) != str(date.today().year):
+            if year_published and int(year_published) < int(date.today().year):
                 has_preservation = False
                 archive_count = 0
 
@@ -266,9 +280,6 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                     }
                 }
 
-                # increment the sample count
-                overall_status["sample-count"] += 1
-
                 for key, value in preservation_statuses.items():
                     preserved, done = value
 
@@ -638,14 +649,7 @@ def member_report(member_id):
             if "published" in sample:
                 year = sample["published"]["date-parts"][0][0]
 
-            if sample["DOI"] == "10.16995/glossa.8784":
-                print("FOUND ARTICLE")
-                print(str(year))
-                print(str(datetime.now().year))
-                print(str(year) != str(datetime.now().year))
-                print(sample)
-
-            if str(year) != str(datetime.now().year):
+            if int(year) < int(datetime.now().year):
                 md5_doi = hashlib.md5(
                     sample["DOI"].lower().encode()
                 ).hexdigest()
