@@ -158,17 +158,17 @@ def show_preservation_for_doi(
     volume = doi["volume"] if "volume" in doi else None
     no = doi["issue"] if "issue" in doi else None
 
-    logging.info(
-        f'Checking {doi["DOI"]}: {container_title} '
-        f"({issns}) v{volume} n{no}"
-    )
-
     year = None
     # "published": {"date-parts": [[2005, 12, 30]]}}}
 
     if "published" in doi:
         year = doi["published"]["date-parts"][0][0]
 
+    logging.info(
+        f'Checking {doi["DOI"]}: {container_title} '
+        f"({issns}) v{volume} n{no} ({year})"
+    )
+
     preserves, doi_echo = show_preservation(
         container_title,
         issns,
